<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
function understrap_remove_scripts() {
	wp_dequeue_style( 'understrap-styles' );
	wp_deregister_style( 'understrap-styles' );
	
	wp_dequeue_script( 'understrap-scripts' );
	wp_deregister_script( 'understrap-scripts' );
	// Removes the parent themes stylesheet and scripts from inc/enqueue.php
}
add_action( 'wp_enqueue_scripts', 'understrap_remove_scripts', 20 );
add_action( 'wp_enqueue_scripts', 'theme_enqueue_styles' );
function theme_enqueue_styles() {
	// Get the theme data
	$the_theme = wp_get_theme();
	wp_enqueue_style( 'child-understrap-styles', get_stylesheet_directory_uri() . '/css/child-theme.min.css', array(), $the_theme->get( 'Version' ) );
	wp_enqueue_script( 'jquery');
    wp_enqueue_script( 'child-understrap-scripts', get_stylesheet_directory_uri() . '/js/child-theme.min.js', array(), $the_theme->get( 'Version' ), true );
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}

function add_child_theme_textdomain() {
    load_child_theme_textdomain( 'understrap-child', get_stylesheet_directory() . '/languages' );
}
add_action( 'after_setup_theme', 'add_child_theme_textdomain' );

/**
 * Changes "site-info" to our boilerplate copyright (David Stockdale).
 * Also adds Log In and Log Out links.
 * (Original "site-info" code can be found in "understrap/inc/hooks.php")
 */
add_action( 'init', 'remove_parent_functions', 15 );
function remove_parent_functions() {
    remove_action( 'understrap_site_info', 'understrap_add_site_info' );
    add_action( 'understrap_site_info', 'understrap_add_site_child_info' );
}
function understrap_add_site_child_info() {
	if(is_user_logged_in()) 
	{
?>
<div class="wrap"><p>Site commissioned from Tees Valley Arts &nbsp; ⁄ &nbsp; Developed by <a rel="nofollow" href=<?php echo 'https://davidstockdalescrapcode.co.uk/' ?>>David Stockdale</a> &nbsp; ⁄ &nbsp; Copyright ©&nbsp;2021 &nbsp; ⁄ &nbsp; <a rel="nofollow" href=<?php echo get_site_url().'/wp-login.php?action=logout&amp;_wpnonce=5969d1c9bc' ?>>Log out</a></p></div>
<?php
	} 
	else 
	{
?>
<div class="wrap"><p>Site commissioned from Tees Valley Arts &nbsp; ⁄ &nbsp; Developed by <a rel="nofollow" href=<?php echo 'https://davidstockdalescrapcode.co.uk/' ?>>David Stockdale</a> &nbsp; ⁄ &nbsp; Copyright ©&nbsp;2021 &nbsp; ⁄ &nbsp; <a rel="nofollow" href=<?php echo get_site_url().'/wp-login.php' ?>>Log in</a></p></div>
<?php
	}
}




/**
 * Removes the site title from embedded content (David Stockdale).
 */
add_filter('embed_site_title_html','__return_false');
/**
 * Adds the author's names to embedded content (David Stockdale).
 */
add_action( 'embed_content', 'embed_author' );
/**
 * Adds the author div to the embed iframe (David Stockdale).
 */
function embed_author() {
	$output .= '<div class="wp-embed-author">By:';
	$coauthors = get_coauthors();
	$loopcheck = 0;
	foreach( $coauthors as $coauthor ):
	/**
	 * Checking if it's the first line to decide if it should be seperated with a comma.
	 */
	if($loopcheck == 0) {
		$loopcheck++;
	} 
	else 
	{
		$output .= ',';
	}
	$output .= ' ';
	$authorArchiveLink = get_author_posts_url($coauthor->ID, $coauthor->user_nicename);
	if ( isset( $coauthor->type ) && 'guest-author' === $coauthor->type ) 
	{
		// we have a guest author
		$output .=  "<a href=$authorArchiveLink> $coauthor->display_name</a>";
	} 
	else 
	{
		$output .=  "<a href=$authorArchiveLink> $coauthor->user_firstname $coauthor->user_lastname</a>";
	}
	endforeach;
	$output .= '.';
	$output .= '</div>';
    echo $output;
}

/**
 * Customises the style/colours of embedded posts (David Stockdale).
 */
add_action( 'embed_head', 'embed_styles' );
/**
 * Embed the plugin's custom styles (David Stockdale).
 */
function embed_styles() {
    echo <<<CSS
<style>
	.wp-embed {
		font-family: "Open Sans", sans-serif;
		background-color:inherit;
		border: none;
	}
	.wp-embed-heading a {
		font-family: "Open Sans", sans-serif;
		color: inherit;
// 		font-size: 1.8rem;
	}
	.wp-embed-author {
		margin-top: 0.5em;
	}
	.wp-embed-author a {
// 		color: #a6191a;
		color: rgb(217, 104, 101);
	}
	.wp-embed-author a:hover {
// 		color: #454545;
		color: darkgray;
 	}
 	.wp-embed-featured-image {
 		width: 150px!important;
		height: 150px!important;
 	}
	.wp-embed-featured-image > a > img {
 		width: 150px!important;
		object-fit: cover;
		height: 150px!important;
 	}
	.wp-embed-excerpt > p {
		word-break:break-word!important;
	}
</style>
CSS;
}

/**
 * Removes the "read more" link auto added to excerpts in UnderStrap (David Stockdale).
 */
add_filter( 'wp_trim_excerpt', 'understrap_all_excerpts_get_more_link' );
function understrap_all_excerpts_get_more_link( $post_excerpt ) {
	return $post_excerpt . '';
}

/**
 * Shortcode for getting coauthors (David Stockdale).
 * [post_authors_posts_links]
 */
add_shortcode( 'post_authors_posts_links', 'post_authors_posts_links_shortcode' );
function post_authors_posts_links_shortcode(  ) {
	return coauthors_posts_links();
}

/**
 * Registers the "authors" widget area (David Stockdale).
 */
add_action( 'widgets_init', 'authors_widgets_init' );
function authors_widgets_init() {
	register_sidebar( array(
		'id'            => 'authors',
		'name'          => __( 'Authors', 'understrap' ),
		'description'   => __( 'Widgets in this area will be shown after posts and pages for the purpose of listing the co-authors and date of publishing.', 'understrap' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}

/**
 * Creates [post_date] shortcode (David Stockdale).
 */
add_shortcode( 'post_date', 'shortcode_post_published_date' );
function shortcode_post_published_date(){
	return get_the_date();
}

/**
 * Disables lazy loading (Done to fix embedded posts not loading consistantly) (David Stockdale).
 */ 
add_filter( 'wp_lazy_loading_enabled', '__return_false' );

/**
 * Makes shortcodes function in text widgets (David Stockdale).
 */
add_filter( 'widget_text', 'shortcode_unautop');
add_filter( 'widget_text', 'do_shortcode');

/*
 * Adding support for excerpts on pages (David Stockdale)
 */
add_post_type_support( 'page', 'excerpt' );

/**
 * Adds custom Gutenberg Image Block Style "Squared (Small)" (David Stockdale).
 */
add_action('init', function() {
	$height_and_width = '9.5em';
	$inline_css = '.is-style-square-small img {
	object-fit: cover!important;
	width: '. $height_and_width . '!important; 
	height: ' . $height_and_width . ';!important}';
	register_block_style('core/image', [
		'name' => 'square-small',
		'label' => __('Squared (Small)', 'txtdomain'),
		'inline_style' => $inline_css
	]);
});

/**
 * Adds custom Gutenberg Image Block Style "Squared (Medium)" (David Stockdale).
 */
add_action('init', function() {
	$height_and_width = '15em';
	$inline_css = '.is-style-square-medium img {
	object-fit: cover!important;
	width: '. $height_and_width . '!important; 
	height: ' . $height_and_width . '!important;}';
	register_block_style('core/image', [
		'name' => 'square-medium',
		'label' => __('Squared (Medium)', 'txtdomain'),
		'inline_style' => $inline_css
	]);
});

/**
 * Adds custom Gutenberg Image Block Style "Squared (Large)" (David Stockdale).
 */
add_action('init', function() {
	$height_and_width = '35em';
	$inline_css = '.is-style-square-large img {
	object-fit: cover!important;
	width: '. $height_and_width . '!important; 
	height: ' . $height_and_width . ';!important}';
	register_block_style('core/image', [
		'name' => 'square-large',
		'label' => __('Squared (Large)', 'txtdomain'),
		'inline_style' => $inline_css
	]);
});

/**
 * Adds custom Gutenberg Image Block Style "Squared (Max)" (David Stockdale).
 */
add_action('init', function() {
	$height_and_width = '80em';
	$inline_css = '.is-style-square-maximum img {
	object-fit: cover!important;
	width: '. $height_and_width . '!important; 
	height: ' . $height_and_width . ';!important}';
	register_block_style('core/image', [
		'name' => 'square-maximum',
		'label' => __('Squared (Max)', 'txtdomain'),
		'inline_style' => $inline_css
	]);
});

/**
 * Adds custom Gutenberg Image Block Style "Circle (Small)" (David Stockdale).
 */
add_action('init', function() {
	$height_and_width = '9.5em';
	$inline_css = '.is-style-circle-small img {
	object-fit: cover!important;
	width: '. $height_and_width . '!important; 
	height: ' . $height_and_width . '!important;
	border-radius: 50%!important;
	-moz-border-radius: 50%!important;
	-webkit-border-radius: 50%!important;
	-o-border-radius: 50%!important;
}';
	register_block_style('core/image', [
		'name' => 'circle-small',
		'label' => __('Circled (Small)', 'txtdomain'),
		'inline_style' => $inline_css
	]);
});

/**
 * Adds custom Gutenberg Image Block Style "Circle (Medium)" (David Stockdale).
 */
add_action('init', function() {
	$height_and_width = '15em';
	$inline_css = '.is-style-circle-medium img {
	object-fit: cover!important;
	width: '. $height_and_width . '!important; 
	height: ' . $height_and_width . '!important;
	border-radius: 50%!important;
	-moz-border-radius: 50%!important;
	-webkit-border-radius: 50%!important;
	-o-border-radius: 50%!important;
}';
	register_block_style('core/image', [
		'name' => 'circle-medium',
		'label' => __('Circled (Medium)', 'txtdomain'),
		'inline_style' => $inline_css
	]);
});

/**
 * Adds custom Gutenberg Image Block Style "Circle (Large)" (David Stockdale).
 */
add_action('init', function() {
	$height_and_width = '35em';
	$inline_css = '.is-style-circle-large img {
	object-fit: cover!important;
	width: '. $height_and_width . '!important; 
	height: ' . $height_and_width . '!important;
	border-radius: 50%!important;
	-moz-border-radius: 50%!important;
	-webkit-border-radius: 50%!important;
	-o-border-radius: 50%!important;
}';
	register_block_style('core/image', [
		'name' => 'circle-large',
		'label' => __('Circled (Large)', 'txtdomain'),
		'inline_style' => $inline_css
	]);
});

/**
 * Adds custom Gutenberg Image Block Style "Circle (Max)" (David Stockdale).
 */
add_action('init', function() {
	$height_and_width = '80em';
	$inline_css = '.is-style-circle-maximum img {
	object-fit: cover!important;
	width: '. $height_and_width . '!important; 
	height: ' . $height_and_width . '!important;
	border-radius: 50%!important;
	-moz-border-radius: 50%!important;
	-webkit-border-radius: 50%!important;
	-o-border-radius: 50%!important;
}';
	register_block_style('core/image', [
		'name' => 'circle-maximum',
		'label' => __('Circled (Max)', 'txtdomain'),
		'inline_style' => $inline_css
	]);
});

/**
 * ADD Tags to Pages - ADDED BY PETER - see https://www.sitepoint.com/wordpress-pages-use-tags/
 */
function tags_support_all() {
	register_taxonomy_for_object_type('post_tag', 'page');
}

/**
 * ensure all tags are included in queries
 */
function tags_support_query($wp_query) {
	if ($wp_query->get('tag')) $wp_query->set('post_type', 'any');
}

/**
 * Tag hooks.
 */
add_action('init', 'tags_support_all');
add_action('pre_get_posts', 'tags_support_query');

/**
 * Adds Font Awsome (https://slickmedia.co.uk/blog/add-fontawesome-5-to-wordpress/)
 * By David Stockdale
 */
add_action( 'wp_enqueue_scripts', 'wpb_load_fa' );
function wpb_load_fa() {
	wp_register_script( 'FontAwesome', 'https://use.fontawesome.com/releases/v5.14.0/js/all.js', null, null, true );
	wp_enqueue_script('FontAwesome');
}

/**
 * Adds Google Search shortcode.
 * [wp_google_search]
 * to get search key goto: https://cse.google.com/cse/all
 */
add_shortcode( 'wp_google_search', 'search_attempt' );
function search_attempt(){
?>
<div class="thing">
	<div class="uk-container uk-container-center">
		<script async src="https://cse.google.com/cse.js?cx=INSERT YOUR GOOGLE SEARCH KEY HERE"></script>
		<div class="gcse-search"></div>
	</div>
</div>
<?php
}

/**
 * Adds additional menu locations.
 */
add_action( 'init', 'register_childtheme_menus' );
function register_childtheme_menus() {
	register_nav_menu('secondary', __( 'Secondary Menu', 'child-theme-textdomain' ));
}














/**
 * Registers the "banner" widget area (David Stockdale).
 */
add_action( 'widgets_init', 'banner_widgets_init' );
function banner_widgets_init() {
	register_sidebar( array(
		'id'            => 'banner',
		'name'          => __( 'Banner', 'understrap' ),
		'description'   => __( 'Widgets in this area will be shown on the cookies and consents banner that pops up when you first view the site.', 'understrap' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}



/**
 * Filter inserts Polly Toggle Shortcode before content.
 */
// add_filter( 'the_content', 'updated_page_content' );
// function updated_page_content( $content )
// {
//      return '
// 	<div class="polly"><p>[showhide type=”polly” more_text=Text-To-Speech less_text=Hide][/showhide]</p></div>' . $content;
// }